==> ejc-assistrmat-impl-3.0.0-20220510.080400-91-sources.jar: com/ejianc/business/assist/store/bean/OtherInDetailEntity.java <==
package com.ejianc.business.assist.store.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 其他入库明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assiststore_other_in_detail")
public class OtherInDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="in_id")
    private Long inId; // 入库ID
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类Id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private Long unit; // 计量单位
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="tax_price")
    private BigDecimal taxPrice; // 单价(含税)
    @TableField(value="price")
    private BigDecimal price; // 单价(无税)
    @TableField(value="instore_mny")
    private BigDecimal instoreMny; // 入库金额(无税)
    @TableField(value="instore_tax_mny")
    private BigDecimal instoreTaxMny; // 入库金额
    @TableField(value="instore_tax")
    private BigDecimal instoreTax; // 入库税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="in_store_num")
    private BigDecimal inStoreNum; // 入库数量
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="trans_scale")
    private BigDecimal transScale; // 转换系数
    @TableField(value="theory_weight")
    private BigDecimal theoryWeight; // 理论重量
    @TableField(value="rough_weight")
    private BigDecimal roughWeight; // 毛重
    @TableField(value="tare_weight")
    private BigDecimal tareWeight; // 皮重
    @TableField(value="suttle_weight")
    private BigDecimal suttleWeight; // 净重
    @TableField(value="deviation_rate")
    private BigDecimal deviationRate; // 偏差率
    @TableField(value="requir_flag")
    private Integer requirFlag; // 是否符合要求：0-否，1-是
    
    
    

    public Long getInId() {
        return inId;
    }

    public void setInId(Long inId) {
        this.inId = inId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnit() {
        return unit;
    }

    public void setUnit(Long unit) {
        this.unit = unit;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getInstoreMny() {
        return instoreMny;
    }

    public void setInstoreMny(BigDecimal instoreMny) {
        this.instoreMny = instoreMny;
    }
    public BigDecimal getInstoreTaxMny() {
        return instoreTaxMny;
    }

    public void setInstoreTaxMny(BigDecimal instoreTaxMny) {
        this.instoreTaxMny = instoreTaxMny;
    }
    public BigDecimal getInstoreTax() {
        return instoreTax;
    }

    public void setInstoreTax(BigDecimal instoreTax) {
        this.instoreTax = instoreTax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getInStoreNum() {
        return inStoreNum;
    }

    public void setInStoreNum(BigDecimal inStoreNum) {
        this.inStoreNum = inStoreNum;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }
    public BigDecimal getTheoryWeight() {
        return theoryWeight;
    }

    public void setTheoryWeight(BigDecimal theoryWeight) {
        this.theoryWeight = theoryWeight;
    }
    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getSuttleWeight() {
        return suttleWeight;
    }

    public void setSuttleWeight(BigDecimal suttleWeight) {
        this.suttleWeight = suttleWeight;
    }
    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }
    public Integer getRequirFlag() {
        return requirFlag;
    }

    public void setRequirFlag(Integer requirFlag) {
        this.requirFlag = requirFlag;
    }
    
}

==> ejc-assistrmat-impl-3.0.0-20220905.093856-168-sources.jar: com/ejianc/business/assist/store/bean/OtherInDetailEntity.java <==
package com.ejianc.business.assist.store.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 其他入库明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assiststore_other_in_detail")
public class OtherInDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="in_id")
    private Long inId; // 入库ID
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类Id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private Long unit; // 计量单位
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="tax_price")
    private BigDecimal taxPrice; // 单价(含税)
    @TableField(value="price")
    private BigDecimal price; // 单价(无税)
    @TableField(value="instore_mny")
    private BigDecimal instoreMny; // 入库金额(无税)
    @TableField(value="instore_tax_mny")
    private BigDecimal instoreTaxMny; // 入库金额
    @TableField(value="instore_tax")
    private BigDecimal instoreTax; // 入库税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="in_store_num")
    private BigDecimal inStoreNum; // 入库数量
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="trans_scale")
    private BigDecimal transScale; // 转换系数
    @TableField(value="theory_weight")
    private BigDecimal theoryWeight; // 理论重量
    @TableField(value="rough_weight")
    private BigDecimal roughWeight; // 毛重
    @TableField(value="tare_weight")
    private BigDecimal tareWeight; // 皮重
    @TableField(value="suttle_weight")
    private BigDecimal suttleWeight; // 净重
    @TableField(value="deviation_rate")
    private BigDecimal deviationRate; // 偏差率
    @TableField(value="requir_flag")
    private Integer requirFlag; // 是否符合要求：0-否，1-是
    @TableField(value="flag")
    private String flag;//标识
    @TableField(value="ton_id")
    private Long tonId; //理论重量单位
    
    
    

    public Long getInId() {
        return inId;
    }

    public void setInId(Long inId) {
        this.inId = inId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnit() {
        return unit;
    }

    public void setUnit(Long unit) {
        this.unit = unit;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getInstoreMny() {
        return instoreMny;
    }

    public void setInstoreMny(BigDecimal instoreMny) {
        this.instoreMny = instoreMny;
    }
    public BigDecimal getInstoreTaxMny() {
        return instoreTaxMny;
    }

    public void setInstoreTaxMny(BigDecimal instoreTaxMny) {
        this.instoreTaxMny = instoreTaxMny;
    }
    public BigDecimal getInstoreTax() {
        return instoreTax;
    }

    public void setInstoreTax(BigDecimal instoreTax) {
        this.instoreTax = instoreTax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getInStoreNum() {
        return inStoreNum;
    }

    public void setInStoreNum(BigDecimal inStoreNum) {
        this.inStoreNum = inStoreNum;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }
    public BigDecimal getTheoryWeight() {
        return theoryWeight;
    }

    public void setTheoryWeight(BigDecimal theoryWeight) {
        this.theoryWeight = theoryWeight;
    }
    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getSuttleWeight() {
        return suttleWeight;
    }

    public void setSuttleWeight(BigDecimal suttleWeight) {
        this.suttleWeight = suttleWeight;
    }
    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }
    public Integer getRequirFlag() {
        return requirFlag;
    }

    public void setRequirFlag(Integer requirFlag) {
        this.requirFlag = requirFlag;
    }

    public String getFlag() {
        return flag;
    }

    public void setFlag(String flag) {
        this.flag = flag;
    }

    public Long getTonId() {
        return tonId;
    }

    public void setTonId(Long tonId) {
        this.tonId = tonId;
    }
}
